@@ -1,8 +1,10 @@
 import json
 import hmac
+import random
+from time import time
 
 from requests import Session, Response
-from typing import Callable, Union
+from typing import Callable, Union, List, Tuple, Dict
 from instauto.api.actions.stubs import _request
 
 from ..structs import Method, State, DeviceProfile, IGProfile, PostLocation
@@ -78,13 +80,18 @@ class PostMixin:
 
         return str(as_json['venues'][0]['external_id'])
 
-    def _upload_image(self, obj: Union[PostStory, PostFeed], quality: int) -> dict:
+    def _upload_image(self, obj: Union[PostStory, PostFeed], quality: int, is_sidecar: bool = False) -> Tuple[Response, dict]:
+        if obj.device is None:
+            d = Device(self.device_profile.manufacturer, self.device_profile.model,
+                       int(self.device_profile.android_sdk_version), self.device_profile.android_release)
+            obj.device = d
+
         as_dict = obj.fill(self).to_dict()
         headers = {
             'x-fb-photo-waterfall-id': str(as_dict.pop('x_fb_waterfall_id')),
             'x-entity-length': str(as_dict.pop('entity_length')),
             'x-entity-name': as_dict.pop('entity_name'),
-            'x-instagram-rupload-params': json.dumps(build_default_rupload_params(obj, quality)),
+            'x-instagram-rupload-params': json.dumps(build_default_rupload_params(obj, quality, is_sidecar)),
             'x-entity-type': as_dict.pop('entity_type'),
             'offset': '0',
             'scene_capture_type': 'standard',
@@ -103,15 +110,10 @@ class PostMixin:
                 data['in'][i] = usertag.to_dict()
             as_dict['usertags'] = json.dumps(data)
 
-        if obj.device is None:
-            d = Device(self.device_profile.manufacturer, self.device_profile.model,
-                       int(self.device_profile.android_sdk_version), self.device_profile.android_release)
-            obj.device = d
-
         with open(path, 'rb') as f:
-            self._request(f'https://i.instagram.com/rupload_igphoto/{headers["x-entity-name"]}', Method.POST,
+            resp = self._request(f'https://i.instagram.com/rupload_igphoto/{headers["x-entity-name"]}', Method.POST,
                           headers=headers, data=f.read())
-        return as_dict
+        return resp, as_dict
 
     def post_post(self, obj: Union[PostStory, PostFeed], quality: int = None) -> Response:
         """Uploads a new picture/video to your Instagram account.
@@ -128,7 +130,7 @@ class PostMixin:
         """
         if quality is None:
             quality = 70
-        as_dict = self._upload_image(obj, quality)
+        as_dict = self._upload_image(obj, quality)[1]
         headers = {
             'retry_context': json.dumps({"num_reupload": 0, "num_step_auto_retry": 0, "num_step_manual_retry": 0})
         }
@@ -192,3 +194,51 @@ class PostMixin:
         resp = self._request(endpoint=endpoint, method=Method.GET)
         users_as_json = [c['user'] for c in resp.json()['comments']]
         return users_as_json
+
+    def post_carousel(self, posts: List[PostFeed], caption: str, quality: int) -> Dict[str, Response]:
+        upload_id = str(time()).split('.')[0]
+
+        data = {
+            "timezone_offset": posts[0].timezone_offset,
+            "_csrftoken": self._session.cookies['csrftoken'],
+            "source_type": str(PostLocation.Feed.value),
+            "_uid": self.state.user_id,
+            "device_id": self.state.android_id,
+            "_uuid": self.state.uuid,
+            "creation_logger_session_id": self._gen_uuid(),
+            "caption": caption,
+            "device": posts[0].to_dict()['device'],
+            "client_sidecar_id": upload_id,
+            "children_metadata": [],
+        }
+
+        for post in posts:
+            data['children_metadata'].append(
+                {
+                    "scene_capture_type": post.scene_capture_type,
+                    "upload_id": post.upload_id,
+                    "caption": post.caption,
+                    "timezone_offset": post.timezone_offset,
+                    "source_type": str(post.source_type),
+                    "scene_type": None,
+                    "edits": json.dumps(post.to_dict()['edits']),
+                    "extra": json.dumps(post.to_dict()['extra']),
+                    "device": json.dumps(post.to_dict()['device'])
+                }
+            )
+            if hasattr(post, 'usertags'):
+                usertags = post.usertags.to_dict()
+                for i, usertag in enumerate(data['in']):
+                    usertags['in'][i] = usertag.to_dict()
+                data['children_metadata'][-1]['usertags'] = json.dumps(usertags)
+
+        headers = {
+            'retry_context': json.dumps({"num_reupload": 0, "num_step_auto_retry": 0, "num_step_manual_retry": 0})
+        }
+
+        responses: Dict[str, Response] = dict()
+        for i, post in enumerate(posts):
+            responses[f'post{i}'] = self._upload_image(post, quality, True)
+
+        responses['configure_sidecar'] = self._request('media/configure_sidecar/', Method.POST, data=data, headers=headers, signed=True)
+        return responses
