@@ -14,6 +14,17 @@ logger = logging.getLogger(__name__)
 
 
 def upload_image_to_feed(client: ApiClient, image_path: str, caption: str = None, location: ps.Location = None) -> bool:
+    """Upload an image to your feed. Location and caption are optional.
+
+    Args:
+        client: your `ApiClient`
+        image_path: path to the image to upload
+        caption: the caption of the post
+        location: the location tag of the post
+
+    Returns:
+        `True` if success else `False`
+    """
     post = ps.PostFeed(
         path=image_path,
         caption=caption or '',
@@ -25,6 +36,15 @@ def upload_image_to_feed(client: ApiClient, image_path: str, caption: str = None
 
 
 def upload_image_to_story(client: ApiClient, image_path: str) -> bool:
+    """Upload an image to your story.
+
+    Args:
+        client: your `ApiClient`
+        image_path: path to the image to upload
+
+    Returns:
+        `True` if success else `False`
+    """
     post = ps.PostStory(
         path=image_path
     )
@@ -34,6 +54,16 @@ def upload_image_to_story(client: ApiClient, image_path: str) -> bool:
 
 
 def update_caption(client: ApiClient, media_id: str, new_caption: str) -> bool:
+    """Update the caption of a post.
+
+    Args:
+        client: your `ApiClient`
+        media_id: the media_id of a post
+        new_caption: the new caption
+
+    Returns:
+        `True` if success else `False`
+    """
     caption = ps.UpdateCaption(
         media_id=media_id,
         caption_text=new_caption
@@ -44,6 +74,15 @@ def update_caption(client: ApiClient, media_id: str, new_caption: str) -> bool:
 
 
 def unlike_post(client: ApiClient, media_id: str) -> bool:
+    """Undo the liking of a post.
+
+    Args:
+        client: your `ApiClient`
+        media_id: the media_id of a post
+
+    Returns:
+        `True` if success else `False`
+    """
     like = ps.Unlike(
         media_id=media_id
     )
@@ -53,6 +92,15 @@ def unlike_post(client: ApiClient, media_id: str) -> bool:
 
 
 def save_post(client: ApiClient, media_id: str) -> bool:
+    """Save a post.
+
+    Args:
+        client: your `ApiClient`
+        media_id: the media_id of a post
+
+    Returns:
+        `True` if success else `False`
+    """
     save = ps.Save(
         media_id=media_id
     )
@@ -62,6 +110,20 @@ def save_post(client: ApiClient, media_id: str) -> bool:
 
 
 def retrieve_posts_from_user(client: ApiClient, limit: int, username: str = None, user_id: str = None) -> List[dict]:
+    """Retrieve x amount of posts from a user.
+
+    Either `user_id` or `username` need to be provided. If both are provided,
+    the user_id takes precedence.
+
+    Args:
+        client: your `ApiClient`
+        limit: maximum amount of posts to retrieve
+        username: username of the account to retrieve posts from
+        user_id: user_id of the account to retrieve posts from
+
+    Returns:
+        A list of Instagram post objects (objects/post.json).
+    """
     if username is None and user_id is None:
         raise ValueError("Either `username` or `user_id` param need to be provider")
 
@@ -87,6 +149,16 @@ def retrieve_posts_from_user(client: ApiClient, limit: int, username: str = None
 
 
 def retrieve_posts_from_tag(client: ApiClient, tag: str, limit: int) -> List[dict]:
+    """Retrieve x amount of posts tagged with a tag.
+
+    Args:
+        client: your `ApiClient`
+        limit: maximum amount of posts to retrieve
+        tag: the tag to search for
+
+    Returns:
+        A list of Instagram post objects (objects/post.json).
+    """
     obj = ps.RetrieveByTag(
         tag_name=tag
     )
@@ -101,16 +173,43 @@ def retrieve_posts_from_tag(client: ApiClient, tag: str, limit: int) -> List[dic
 
 
 def get_likers_of_post(client: ApiClient, media_id: str) -> List[dict]:
+    """Get users that liked a post.
+
+    Args:
+        client: your `ApiClient`
+        media_id: the post to retrieve the likers from
+
+    Returns:
+        A list of Instagram user objects (objects/user.json).
+    """
     logger.info(f"Getting likers of {media_id}")
     return client.post_get_likers(RetrieveLikers(media_id))
 
 
 def get_commenters_of_post(client: ApiClient, media_id: str) -> List[dict]:
+    """Get users that commented on a post.
+
+    Args:
+        client: your `ApiClient`
+        media_id: the post to retrieve the commenters from
+
+    Returns:
+        A list of Instagram user objects (objects/post.json).
+    """
     logger.info(f"Getting commenters of {media_id}")
     return client.post_get_commenters(RetrieveCommenters(media_id))
 
 
 def like_post(client: ApiClient, media_id: str) -> bool:
+    """Like a post.
+
+    Args:
+        client: your `ApiClient`
+        media_id: the post to like
+
+    Returns:
+        `True` if success else `False`
+    """
     like = ps.Like(
         media_id=media_id
     )
@@ -120,6 +219,16 @@ def like_post(client: ApiClient, media_id: str) -> bool:
 
 
 def comment_post(client: ApiClient, media_id: str, comment: str) -> bool:
+    """Leave a comment on a post.
+
+    Args:
+        client: your `ApiClient`
+        media_id: the post to comment on
+        comment: the comment to place
+
+    Returns:
+        `True` if success else `False`
+    """
     comment = ps.Comment(
         media_id=media_id,
         comment_text=comment
